==> haskell-hashable-time-0.3-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hashable-time
version:              0.3
visibility:           public
id:                   hashable-time-0.3-KiRmHUhLIZaGkBWGJIhdeH
key:                  hashable-time-0.3-KiRmHUhLIZaGkBWGJIhdeH
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  e50894b4c148fbe51770bf5a0b86c970
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable-time
hs-libraries:         HShashable-time-0.3-KiRmHUhLIZaGkBWGJIhdeH
depends:              base-4.18.2.1 time-compat-1.9.8-Jxw2UguI3huFXhVcheAJ7
haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-time-0.3-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hashable-time
version:              0.3
visibility:           public
id:                   hashable-time-0.3-83rjETf2vgRHxYmPLda6gQ
key:                  hashable-time-0.3-83rjETf2vgRHxYmPLda6gQ
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  74dfea9687f1b9866311a81f947a080d
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable-time
hs-libraries:         HShashable-time-0.3-83rjETf2vgRHxYmPLda6gQ
depends:
    base-4.18.2.1 time-compat-1.9.8-Ln5uX6BKYFGFxUe2zKnSOu

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
